@@ -28,8 +28,8 @@
 #include <QPainter>
 #include <QTimeLine>
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <QDebug>
+#include <KLocalizedString>
 #include "molecule.h"
 #include "playfield.h"
 
@@ -50,7 +50,7 @@ ArrowFieldItem::ArrowFieldItem( KGameRenderer* renderer, PlayField::Direction di
     setOpacity(0.0); //start invisible
     m_timeLine = new QTimeLine(200);
     m_timeLine->setFrameRange( 0, 30 );
-    connect(m_timeLine, SIGNAL(valueChanged(qreal)), SLOT(setOpacity(qreal)) );
+    connect(m_timeLine, &QTimeLine::valueChanged, this, &ArrowFieldItem::setOpacity);
 }
 
 ArrowFieldItem::~ArrowFieldItem()
@@ -197,9 +197,10 @@ QPixmap AtomFieldItem::renderAtom( KGameRenderer* renderer, const atom& at, int
 // ----------------- MoleculePreviewItem ----------------------------
 
 MoleculePreviewItem::MoleculePreviewItem( PlayField* scene )
-    : QGraphicsItem( 0, scene ), m_renderer(scene->renderer()), m_width(0),
+    : QGraphicsItem( 0 ), m_renderer(scene->renderer()), m_width(0),
       m_atomSize(20), m_maxAtomSize(30), m_mol( 0 )
 {
+   scene->addItem(this);
 }
 
 MoleculePreviewItem::~MoleculePreviewItem()
@@ -262,4 +263,4 @@ void MoleculePreviewItem::paint( QPainter * painter, const QStyleOptionGraphicsI
     painter->restore();
 }
 
-#include "fielditem.moc"
+
